Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Lake Formation.

Actions, resources, and condition keys for AWS Lake Formation - Service Authorization Reference

# Actions, resources, and condition keys for AWS Lake Formation

AWS Lake Formation (service prefix: `lakeformation` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Lake Formation
- Resource types defined by AWS Lake Formation
- Condition keys for AWS Lake Formation

## Actions defined by AWS Lake Formation

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddLFTagsToResource | Grants permission to attach Lake Formation tags to catalog resources | Tagging |  |  |
BatchGrantPermissions | Grants permission to data lake permissions to one or more principals in a batch | Permissions management |  |  |
BatchRevokePermissions | Grants permission to revoke data lake permissions from one or more principals in a batch | Permissions management |  |  |
CancelTransaction | Grants permission to cancel the given transaction | Write |  |  |
CommitTransaction | Grants permission to commit the given transaction | Write |  |  |
CreateDataCellsFilter | Grants permission to create a Lake Formation data cell filter | Write |  |  |
CreateLFTag | Grants permission to create a Lake Formation tag | Write |  |  |
CreateLakeFormationIdentityCenterConfiguration | Grants permission to create an IAM Identity Center connection with Lake Formation to allow IAM Identity Center users and groups to access Data Catalog resources | Write |  |  |
CreateLakeFormationOptIn | Enforce Lake Formation permissions for the given databases, tables, and principals | Write |  |  |
DeleteDataCellsFilter | Grants permission to delete a Lake Formation data cell filter | Write |  |  |
DeleteLFTag | Grants permission to delete a Lake Formation tag | Write |  |  |
DeleteLakeFormationIdentityCenterConfiguration | Grants permission to delete an IAM Identity Center connection with Lake Formation | Write |  |  |
DeleteLakeFormationOptIn | Remove the Lake Formation permissions enforcement of the given databases, tables, and principals | Write |  |  |
DeleteObjectsOnCancel | Grants permission to delete the specified objects if the transaction is canceled | Write |  |  |
DeregisterResource | Grants permission to deregister a registered location | Write |  |  |
DescribeLakeFormationIdentityCenterConfiguration | Grants permission to describe the IAM Identity Center connection with Lake Formation | Read |  |  |
DescribeResource | Grants permission to describe a registered location | Read |  |  |
DescribeTransaction | Grants permission to get status of the given transaction | Read |  |  |
ExtendTransaction | Grants permission to extend the timeout of the given transaction | Write |  |  |
GetDataAccess | Grants permission to virtual data lake access | Write |  |  |
GetDataCellsFilter | Grants permission to retrieve a Lake Formation data cell filter | Read |  |  |
GetDataLakeSettings | Grants permission to retrieve data lake settings such as the list of data lake administrators and database and table default permissions | Read |  |  |
GetEffectivePermissionsForPath | Grants permission to retrieve permissions attached to resources in the given path | Read |  |  |
GetLFTag | Grants permission to retrieve a Lake Formation tag | Read |  |  |
GetQueryState | Grants permission to retrieve the state of the given query | Read |  |  | lakeformation:StartQueryPlanning
GetQueryStatistics | Grants permission to retrieve the statistics for the given query | Read |  |  | lakeformation:StartQueryPlanning
GetResourceLFTags | Grants permission to retrieve lakeformation tags on a catalog resource | Read |  |  |
GetTableObjects | Grants permission to retrieve objects from a table | Read |  |  |
GetWorkUnitResults | Grants permission to retrieve the results for the given work units | Read |  |  | lakeformation:GetWorkUnits lakeformation:StartQueryPlanning
GetWorkUnits | Grants permission to retrieve the work units for the given query | Read |  |  | lakeformation:StartQueryPlanning
GrantPermissions | Grants permission to data lake permissions to a principal | Permissions management |  |  |
ListDataCellsFilter | Grants permission to list cell filters | List |  |  |
ListLFTags | Grants permission to list Lake Formation tags | Read |  |  |
ListLakeFormationOptIns | Retrieve the current list of resources and principals that are opt in to enforce Lake Formation permissions | List |  |  |
ListPermissions | Grants permission to list permissions filtered by principal or resource | List |  |  |
ListResources | Grants permission to List registered locations | List |  |  |
ListTableStorageOptimizers | Grants permission to list all the storage optimizers for the Governed table | List |  |  |
ListTransactions | Grants permission to list all transactions in the system | List |  |  |
PutDataLakeSettings | Grants permission to overwrite data lake settings such as the list of data lake administrators and database and table default permissions | Permissions management |  |  |
RegisterResource | Grants permission to register a new location to be managed by Lake Formation | Write |  |  |
RemoveLFTagsFromResource | Grants permission to remove lakeformation tags from catalog resources | Tagging |  |  |
RevokePermissions | Grants permission to revoke data lake permissions from a principal | Permissions management |  |  |
SearchDatabasesByLFTags | Grants permission to list catalog databases with Lake Formation tags | Read |  |  |
SearchTablesByLFTags | Grants permission to list catalog tables with Lake Formation tags | Read |  |  |
StartQueryPlanning | Grants permission to initiate the planning of the given query | Write |  |  |
StartTransaction | Grants permission to start a new transaction | Write |  |  |
UpdateDataCellsFilter | Grants permission to update a Lake Formation data cell filter | Write |  |  |
UpdateLFTag | Grants permission to update a Lake Formation tag | Write |  |  |
UpdateLakeFormationIdentityCenterConfiguration | Grants permission to update the IAM Identity Center connection parameters | Write |  |  |
UpdateResource | Grants permission to update a registered location | Write |  |  |
UpdateTableObjects | Grants permission to add or delete the specified objects to or from a table | Write |  |  |
UpdateTableStorageOptimizer | Grants permission to update the configuration of the storage optimizer for the Governed table | Write |  |  |

## Resource types defined by AWS Lake Formation

AWS Lake Formation does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to AWS Lake Formation, specify `"Resource": "*"` in your policy.

## Condition keys for AWS Lake Formation

Lake Formation has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.